# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/ratelimit/limit_params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)dydxprotocol/ratelimit/limit_params.proto\x12\x16\x64ydxprotocol.ratelimit\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"U\n\x0bLimitParams\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x37\n\x08limiters\x18\x02 \x03(\x0b\x32\x1f.dydxprotocol.ratelimit.LimiterB\x04\xc8\xde\x1f\x00\"\xbc\x01\n\x07Limiter\x12\x33\n\x06period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x62\n\x10\x62\x61seline_minimum\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x18\n\x10\x62\x61seline_tvl_ppm\x18\x04 \x01(\rB=Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.ratelimit.limit_params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/types'
  _globals['_LIMITPARAMS'].fields_by_name['limiters']._loaded_options = None
  _globals['_LIMITPARAMS'].fields_by_name['limiters']._serialized_options = b'\310\336\037\000'
  _globals['_LIMITER'].fields_by_name['period']._loaded_options = None
  _globals['_LIMITER'].fields_by_name['period']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_LIMITER'].fields_by_name['baseline_minimum']._loaded_options = None
  _globals['_LIMITER'].fields_by_name['baseline_minimum']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LIMITPARAMS']._serialized_start=123
  _globals['_LIMITPARAMS']._serialized_end=208
  _globals['_LIMITER']._serialized_start=211
  _globals['_LIMITER']._serialized_end=399
# @@protoc_insertion_point(module_scope)
