# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as dydxprotocol_dot_clob_dot_block__rate__limit__config__pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as dydxprotocol_dot_clob_dot_equity__tier__limit__config__pb2
from v4_proto.dydxprotocol.clob import order_pb2 as dydxprotocol_dot_clob_dot_order__pb2
from v4_proto.dydxprotocol.clob import matches_pb2 as dydxprotocol_dot_clob_dot_matches__pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as dydxprotocol_dot_clob_dot_liquidations__config__pb2
from v4_proto.dydxprotocol.clob import mev_pb2 as dydxprotocol_dot_clob_dot_mev__pb2
from v4_proto.dydxprotocol.indexer.off_chain_updates import off_chain_updates_pb2 as dydxprotocol_dot_indexer_dot_off__chain__updates_dot_off__chain__updates__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/clob/query.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a/dydxprotocol/clob/block_rate_limit_config.proto\x1a!dydxprotocol/clob/clob_pair.proto\x1a\x30\x64ydxprotocol/clob/equity_tier_limit_config.proto\x1a\x1d\x64ydxprotocol/clob/order.proto\x1a\x1f\x64ydxprotocol/clob/matches.proto\x1a+dydxprotocol/clob/liquidations_config.proto\x1a\x1b\x64ydxprotocol/clob/mev.proto\x1a>dydxprotocol/indexer/off_chain_updates/off_chain_updates.proto\"%\n\x17QueryGetClobPairRequest\x12\n\n\x02id\x18\x01 \x01(\r\"M\n\x15QueryClobPairResponse\x12\x34\n\tclob_pair\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00\"U\n\x17QueryAllClobPairRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x18QueryClobPairAllResponse\x12\x34\n\tclob_pair\x18\x01 \x03(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xb1\x01\n\x1fMevNodeToNodeCalculationRequest\x12\x46\n\x16\x62lock_proposer_matches\x18\x01 \x01(\x0b\x32&.dydxprotocol.clob.ValidatorMevMatches\x12\x46\n\x15validator_mev_metrics\x18\x02 \x01(\x0b\x32\'.dydxprotocol.clob.MevNodeToNodeMetrics\"\xcc\x01\n MevNodeToNodeCalculationResponse\x12^\n\x07results\x18\x01 \x03(\x0b\x32G.dydxprotocol.clob.MevNodeToNodeCalculationResponse.MevAndVolumePerClobB\x04\xc8\xde\x1f\x00\x1aH\n\x13MevAndVolumePerClob\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x01(\r\x12\x0b\n\x03mev\x18\x02 \x01(\x02\x12\x0e\n\x06volume\x18\x03 \x01(\x04\"*\n(QueryEquityTierLimitConfigurationRequest\"\x84\x01\n)QueryEquityTierLimitConfigurationResponse\x12W\n\x18\x65quity_tier_limit_config\x18\x01 \x01(\x0b\x32/.dydxprotocol.clob.EquityTierLimitConfigurationB\x04\xc8\xde\x1f\x00\")\n\'QueryBlockRateLimitConfigurationRequest\"\x81\x01\n(QueryBlockRateLimitConfigurationResponse\x12U\n\x17\x62lock_rate_limit_config\x18\x01 \x01(\x0b\x32..dydxprotocol.clob.BlockRateLimitConfigurationB\x04\xc8\xde\x1f\x00\"O\n\x19QueryStatefulOrderRequest\x12\x32\n\x08order_id\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"\x8e\x01\n\x1aQueryStatefulOrderResponse\x12H\n\x0forder_placement\x18\x01 \x01(\x0b\x32).dydxprotocol.clob.LongTermOrderPlacementB\x04\xc8\xde\x1f\x00\x12\x13\n\x0b\x66ill_amount\x18\x02 \x01(\x04\x12\x11\n\ttriggered\x18\x03 \x01(\x08\"\'\n%QueryLiquidationsConfigurationRequest\"r\n&QueryLiquidationsConfigurationResponse\x12H\n\x13liquidations_config\x18\x01 \x01(\x0b\x32%.dydxprotocol.clob.LiquidationsConfigB\x04\xc8\xde\x1f\x00\"5\n\x1dStreamOrderbookUpdatesRequest\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x03(\r\"\x81\x01\n\x1eStreamOrderbookUpdatesResponse\x12\x36\n\x07updates\x18\x01 \x03(\x0b\x32\x1f.dydxprotocol.clob.StreamUpdateB\x04\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\r\x12\x11\n\texec_mode\x18\x03 \x01(\r\"\xa4\x01\n\x0cStreamUpdate\x12\x44\n\x10orderbook_update\x18\x01 \x01(\x0b\x32(.dydxprotocol.clob.StreamOrderbookUpdateH\x00\x12<\n\norder_fill\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.StreamOrderbookFillH\x00\x42\x10\n\x0eupdate_message\"z\n\x15StreamOrderbookUpdate\x12O\n\x07updates\x18\x01 \x03(\x0b\x32\x38.dydxprotocol.indexer.off_chain_updates.OffChainUpdateV1B\x04\xc8\xde\x1f\x00\x12\x10\n\x08snapshot\x18\x02 \x01(\x08\"\x93\x01\n\x13StreamOrderbookFill\x12\x30\n\nclob_match\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.clob.ClobMatch\x12.\n\x06orders\x18\x02 \x03(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\x12\x1a\n\x0c\x66ill_amounts\x18\x03 \x03(\x04\x42\x04\xc8\xde\x1f\x00\x32\x9e\n\n\x05Query\x12\x8b\x01\n\x08\x43lobPair\x12*.dydxprotocol.clob.QueryGetClobPairRequest\x1a(.dydxprotocol.clob.QueryClobPairResponse\")\x82\xd3\xe4\x93\x02#\x12!/dydxprotocol/clob/clob_pair/{id}\x12\x8c\x01\n\x0b\x43lobPairAll\x12*.dydxprotocol.clob.QueryAllClobPairRequest\x1a+.dydxprotocol.clob.QueryClobPairAllResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/dydxprotocol/clob/clob_pair\x12\xbf\x01\n\x18MevNodeToNodeCalculation\x12\x32.dydxprotocol.clob.MevNodeToNodeCalculationRequest\x1a\x33.dydxprotocol.clob.MevNodeToNodeCalculationResponse\":\x82\xd3\xe4\x93\x02\x34\"//dydxprotocol/clob/mev_node_to_node_calculation:\x01*\x12\xc1\x01\n\x1c\x45quityTierLimitConfiguration\x12;.dydxprotocol.clob.QueryEquityTierLimitConfigurationRequest\x1a<.dydxprotocol.clob.QueryEquityTierLimitConfigurationResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/dydxprotocol/clob/equity_tier\x12\xbd\x01\n\x1b\x42lockRateLimitConfiguration\x12:.dydxprotocol.clob.QueryBlockRateLimitConfigurationRequest\x1a;.dydxprotocol.clob.QueryBlockRateLimitConfigurationResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/dydxprotocol/clob/block_rate\x12\xc0\x01\n\x19LiquidationsConfiguration\x12\x38.dydxprotocol.clob.QueryLiquidationsConfigurationRequest\x1a\x39.dydxprotocol.clob.QueryLiquidationsConfigurationResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/clob/liquidations_config\x12n\n\rStatefulOrder\x12,.dydxprotocol.clob.QueryStatefulOrderRequest\x1a-.dydxprotocol.clob.QueryStatefulOrderResponse\"\x00\x12\x7f\n\x16StreamOrderbookUpdates\x12\x30.dydxprotocol.clob.StreamOrderbookUpdatesRequest\x1a\x31.dydxprotocol.clob.StreamOrderbookUpdatesResponse0\x01\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_QUERYCLOBPAIRRESPONSE'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_QUERYCLOBPAIRRESPONSE'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCLOBPAIRALLRESPONSE'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_QUERYCLOBPAIRALLRESPONSE'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MEVNODETONODECALCULATIONRESPONSE'].fields_by_name['results']._loaded_options = None
  _globals['_MEVNODETONODECALCULATIONRESPONSE'].fields_by_name['results']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE'].fields_by_name['equity_tier_limit_config']._loaded_options = None
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE'].fields_by_name['equity_tier_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE'].fields_by_name['block_rate_limit_config']._loaded_options = None
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE'].fields_by_name['block_rate_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSTATEFULORDERREQUEST'].fields_by_name['order_id']._loaded_options = None
  _globals['_QUERYSTATEFULORDERREQUEST'].fields_by_name['order_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSTATEFULORDERRESPONSE'].fields_by_name['order_placement']._loaded_options = None
  _globals['_QUERYSTATEFULORDERRESPONSE'].fields_by_name['order_placement']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE'].fields_by_name['liquidations_config']._loaded_options = None
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE'].fields_by_name['liquidations_config']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKUPDATESRESPONSE'].fields_by_name['updates']._loaded_options = None
  _globals['_STREAMORDERBOOKUPDATESRESPONSE'].fields_by_name['updates']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKUPDATE'].fields_by_name['updates']._loaded_options = None
  _globals['_STREAMORDERBOOKUPDATE'].fields_by_name['updates']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['orders']._loaded_options = None
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['fill_amounts']._loaded_options = None
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['fill_amounts']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['ClobPair']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClobPair']._serialized_options = b'\202\323\344\223\002#\022!/dydxprotocol/clob/clob_pair/{id}'
  _globals['_QUERY'].methods_by_name['ClobPairAll']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClobPairAll']._serialized_options = b'\202\323\344\223\002\036\022\034/dydxprotocol/clob/clob_pair'
  _globals['_QUERY'].methods_by_name['MevNodeToNodeCalculation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MevNodeToNodeCalculation']._serialized_options = b'\202\323\344\223\0024\"//dydxprotocol/clob/mev_node_to_node_calculation:\001*'
  _globals['_QUERY'].methods_by_name['EquityTierLimitConfiguration']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EquityTierLimitConfiguration']._serialized_options = b'\202\323\344\223\002 \022\036/dydxprotocol/clob/equity_tier'
  _globals['_QUERY'].methods_by_name['BlockRateLimitConfiguration']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BlockRateLimitConfiguration']._serialized_options = b'\202\323\344\223\002\037\022\035/dydxprotocol/clob/block_rate'
  _globals['_QUERY'].methods_by_name['LiquidationsConfiguration']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LiquidationsConfiguration']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/clob/liquidations_config'
  _globals['_QUERYGETCLOBPAIRREQUEST']._serialized_start=484
  _globals['_QUERYGETCLOBPAIRREQUEST']._serialized_end=521
  _globals['_QUERYCLOBPAIRRESPONSE']._serialized_start=523
  _globals['_QUERYCLOBPAIRRESPONSE']._serialized_end=600
  _globals['_QUERYALLCLOBPAIRREQUEST']._serialized_start=602
  _globals['_QUERYALLCLOBPAIRREQUEST']._serialized_end=687
  _globals['_QUERYCLOBPAIRALLRESPONSE']._serialized_start=690
  _globals['_QUERYCLOBPAIRALLRESPONSE']._serialized_end=831
  _globals['_MEVNODETONODECALCULATIONREQUEST']._serialized_start=834
  _globals['_MEVNODETONODECALCULATIONREQUEST']._serialized_end=1011
  _globals['_MEVNODETONODECALCULATIONRESPONSE']._serialized_start=1014
  _globals['_MEVNODETONODECALCULATIONRESPONSE']._serialized_end=1218
  _globals['_MEVNODETONODECALCULATIONRESPONSE_MEVANDVOLUMEPERCLOB']._serialized_start=1146
  _globals['_MEVNODETONODECALCULATIONRESPONSE_MEVANDVOLUMEPERCLOB']._serialized_end=1218
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONREQUEST']._serialized_start=1220
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONREQUEST']._serialized_end=1262
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_start=1265
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_end=1397
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONREQUEST']._serialized_start=1399
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONREQUEST']._serialized_end=1440
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_start=1443
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_end=1572
  _globals['_QUERYSTATEFULORDERREQUEST']._serialized_start=1574
  _globals['_QUERYSTATEFULORDERREQUEST']._serialized_end=1653
  _globals['_QUERYSTATEFULORDERRESPONSE']._serialized_start=1656
  _globals['_QUERYSTATEFULORDERRESPONSE']._serialized_end=1798
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONREQUEST']._serialized_start=1800
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONREQUEST']._serialized_end=1839
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE']._serialized_start=1841
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE']._serialized_end=1955
  _globals['_STREAMORDERBOOKUPDATESREQUEST']._serialized_start=1957
  _globals['_STREAMORDERBOOKUPDATESREQUEST']._serialized_end=2010
  _globals['_STREAMORDERBOOKUPDATESRESPONSE']._serialized_start=2013
  _globals['_STREAMORDERBOOKUPDATESRESPONSE']._serialized_end=2142
  _globals['_STREAMUPDATE']._serialized_start=2145
  _globals['_STREAMUPDATE']._serialized_end=2309
  _globals['_STREAMORDERBOOKUPDATE']._serialized_start=2311
  _globals['_STREAMORDERBOOKUPDATE']._serialized_end=2433
  _globals['_STREAMORDERBOOKFILL']._serialized_start=2436
  _globals['_STREAMORDERBOOKFILL']._serialized_end=2583
  _globals['_QUERY']._serialized_start=2586
  _globals['_QUERY']._serialized_end=3896
# @@protoc_insertion_point(module_scope)
