# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/rewards/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.rewards import params_pb2 as dydxprotocol_dot_rewards_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/rewards/query.proto\x12\x14\x64ydxprotocol.rewards\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a!dydxprotocol/rewards/params.proto\"\x14\n\x12QueryParamsRequest\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.rewards.ParamsB\x04\xc8\xde\x1f\x00\x32\x90\x01\n\x05Query\x12\x86\x01\n\x06Params\x12(.dydxprotocol.rewards.QueryParamsRequest\x1a).dydxprotocol.rewards.QueryParamsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/dydxprotocol/v4/rewards/paramsB;Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.rewards.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002!\022\037/dydxprotocol/v4/rewards/params'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=145
  _globals['_QUERYPARAMSREQUEST']._serialized_end=165
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=167
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=240
  _globals['_QUERY']._serialized_start=243
  _globals['_QUERY']._serialized_end=387
# @@protoc_insertion_point(module_scope)
