# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/query.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\"\x14\n\x12QueryParamsRequest\"G\n\x13QueryParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.vault.ParamsB\x04\xc8\xde\x1f\x00\"P\n\x11QueryVaultRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"\xc7\x01\n\x12QueryVaultResponse\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12\x43\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06\x65quity\x18\x03 \x01(\x04\x12\x11\n\tinventory\x18\x04 \x01(\x04\x12\x14\n\x0ctotal_shares\x18\x05 \x01(\x04\"S\n\x15QueryAllVaultsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x16QueryAllVaultsResponse\x12\x36\n\x06vaults\x18\x01 \x03(\x0b\x32&.dydxprotocol.vault.QueryVaultResponse\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x92\x01\n\x17QueryOwnerSharesRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"d\n\nOwnerShare\x12\'\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12-\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumShares\"\x8d\x01\n\x18QueryOwnerSharesResponse\x12\x34\n\x0cowner_shares\x18\x01 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShare\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xbf\x04\n\x05Query\x12}\n\x06Params\x12&.dydxprotocol.vault.QueryParamsRequest\x1a\'.dydxprotocol.vault.QueryParamsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/dydxprotocol/vault/params\x12\x89\x01\n\x05Vault\x12%.dydxprotocol.vault.QueryVaultRequest\x1a&.dydxprotocol.vault.QueryVaultResponse\"1\x82\xd3\xe4\x93\x02+\x12)/dydxprotocol/vault/vault/{type}/{number}\x12\x85\x01\n\tAllVaults\x12).dydxprotocol.vault.QueryAllVaultsRequest\x1a*.dydxprotocol.vault.QueryAllVaultsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/dydxprotocol/vault/vault\x12\xa2\x01\n\x0bOwnerShares\x12+.dydxprotocol.vault.QueryOwnerSharesRequest\x1a,.dydxprotocol.vault.QueryOwnerSharesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/dydxprotocol/vault/owner_shares/{type}/{number}B9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_OWNERSHARE'].fields_by_name['owner']._loaded_options = None
  _globals['_OWNERSHARE'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\034\022\032/dydxprotocol/vault/params'
  _globals['_QUERY'].methods_by_name['Vault']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Vault']._serialized_options = b'\202\323\344\223\002+\022)/dydxprotocol/vault/vault/{type}/{number}'
  _globals['_QUERY'].methods_by_name['AllVaults']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllVaults']._serialized_options = b'\202\323\344\223\002\033\022\031/dydxprotocol/vault/vault'
  _globals['_QUERY'].methods_by_name['OwnerShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OwnerShares']._serialized_options = b'\202\323\344\223\0022\0220/dydxprotocol/vault/owner_shares/{type}/{number}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=285
  _globals['_QUERYPARAMSREQUEST']._serialized_end=305
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=307
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=378
  _globals['_QUERYVAULTREQUEST']._serialized_start=380
  _globals['_QUERYVAULTREQUEST']._serialized_end=460
  _globals['_QUERYVAULTRESPONSE']._serialized_start=463
  _globals['_QUERYVAULTRESPONSE']._serialized_end=662
  _globals['_QUERYALLVAULTSREQUEST']._serialized_start=664
  _globals['_QUERYALLVAULTSREQUEST']._serialized_end=747
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_start=750
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_end=891
  _globals['_QUERYOWNERSHARESREQUEST']._serialized_start=894
  _globals['_QUERYOWNERSHARESREQUEST']._serialized_end=1040
  _globals['_OWNERSHARE']._serialized_start=1042
  _globals['_OWNERSHARE']._serialized_end=1142
  _globals['_QUERYOWNERSHARESRESPONSE']._serialized_start=1145
  _globals['_QUERYOWNERSHARESRESPONSE']._serialized_end=1286
  _globals['_QUERY']._serialized_start=1289
  _globals['_QUERY']._serialized_end=1864
# @@protoc_insertion_point(module_scope)
