# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/indexer/off_chain_updates/off_chain_updates.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.indexer.shared import removal_reason_pb2 as dydxprotocol_dot_indexer_dot_shared_dot_removal__reason__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_clob__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>dydxprotocol/indexer/off_chain_updates/off_chain_updates.proto\x12&dydxprotocol.indexer.off_chain_updates\x1a\x30\x64ydxprotocol/indexer/shared/removal_reason.proto\x1a+dydxprotocol/indexer/protocol/v1/clob.proto\"\xc5\x02\n\x0cOrderPlaceV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x12\x63\n\x10placement_status\x18\x02 \x01(\x0e\x32I.dydxprotocol.indexer.off_chain_updates.OrderPlaceV1.OrderPlacementStatus\"\x90\x01\n\x14OrderPlacementStatus\x12&\n\"ORDER_PLACEMENT_STATUS_UNSPECIFIED\x10\x00\x12-\n)ORDER_PLACEMENT_STATUS_BEST_EFFORT_OPENED\x10\x01\x12!\n\x1dORDER_PLACEMENT_STATUS_OPENED\x10\x02\"\xae\x03\n\rOrderRemoveV1\x12J\n\x10removed_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12?\n\x06reason\x18\x02 \x01(\x0e\x32/.dydxprotocol.indexer.shared.OrderRemovalReason\x12`\n\x0eremoval_status\x18\x03 \x01(\x0e\x32H.dydxprotocol.indexer.off_chain_updates.OrderRemoveV1.OrderRemovalStatus\"\xad\x01\n\x12OrderRemovalStatus\x12$\n ORDER_REMOVAL_STATUS_UNSPECIFIED\x10\x00\x12-\n)ORDER_REMOVAL_STATUS_BEST_EFFORT_CANCELED\x10\x01\x12!\n\x1dORDER_REMOVAL_STATUS_CANCELED\x10\x02\x12\x1f\n\x1bORDER_REMOVAL_STATUS_FILLED\x10\x03\"r\n\rOrderUpdateV1\x12\x42\n\x08order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12\x1d\n\x15total_filled_quantums\x18\x02 \x01(\x04\"\x8f\x02\n\x10OffChainUpdateV1\x12K\n\x0border_place\x18\x01 \x01(\x0b\x32\x34.dydxprotocol.indexer.off_chain_updates.OrderPlaceV1H\x00\x12M\n\x0corder_remove\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.off_chain_updates.OrderRemoveV1H\x00\x12M\n\x0corder_update\x18\x03 \x01(\x0b\x32\x35.dydxprotocol.indexer.off_chain_updates.OrderUpdateV1H\x00\x42\x10\n\x0eupdate_messageBKZIgithub.com/dydxprotocol/v4-chain/protocol/indexer/off_chain_updates/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.off_chain_updates.off_chain_updates_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZIgithub.com/dydxprotocol/v4-chain/protocol/indexer/off_chain_updates/types'
  _globals['_ORDERPLACEV1']._serialized_start=202
  _globals['_ORDERPLACEV1']._serialized_end=527
  _globals['_ORDERPLACEV1_ORDERPLACEMENTSTATUS']._serialized_start=383
  _globals['_ORDERPLACEV1_ORDERPLACEMENTSTATUS']._serialized_end=527
  _globals['_ORDERREMOVEV1']._serialized_start=530
  _globals['_ORDERREMOVEV1']._serialized_end=960
  _globals['_ORDERREMOVEV1_ORDERREMOVALSTATUS']._serialized_start=787
  _globals['_ORDERREMOVEV1_ORDERREMOVALSTATUS']._serialized_end=960
  _globals['_ORDERUPDATEV1']._serialized_start=962
  _globals['_ORDERUPDATEV1']._serialized_end=1076
  _globals['_OFFCHAINUPDATEV1']._serialized_start=1079
  _globals['_OFFCHAINUPDATEV1']._serialized_end=1350
# @@protoc_insertion_point(module_scope)
