# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/delaymsg/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.delaymsg import delayed_message_pb2 as dydxprotocol_dot_delaymsg_dot_delayed__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/delaymsg/genesis.proto\x12\x15\x64ydxprotocol.delaymsg\x1a+dydxprotocol/delaymsg/delayed_message.proto\"p\n\x0cGenesisState\x12?\n\x10\x64\x65layed_messages\x18\x01 \x03(\x0b\x32%.dydxprotocol.delaymsg.DelayedMessage\x12\x1f\n\x17next_delayed_message_id\x18\x02 \x01(\rB<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_GENESISSTATE']._serialized_start=107
  _globals['_GENESISSTATE']._serialized_end=219
# @@protoc_insertion_point(module_scope)
