# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/govplus/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/govplus/tx.proto\x12\x14\x64ydxprotocol.govplus\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"\xe6\x02\n\x11MsgSlashValidator\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12\x19\n\x11infraction_height\x18\x03 \x01(\r\x12m\n\x1btokens_at_infraction_height\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12L\n\x0cslash_factor\x18\x05 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgSlashValidatorResponse2q\n\x03Msg\x12j\n\x0eSlashValidator\x12\'.dydxprotocol.govplus.MsgSlashValidator\x1a/.dydxprotocol.govplus.MsgSlashValidatorResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/govplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.govplus.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/govplus/types'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['tokens_at_infraction_height']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['tokens_at_infraction_height']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['slash_factor']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['slash_factor']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_MSGSLASHVALIDATOR']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSLASHVALIDATOR']._serialized_start=149
  _globals['_MSGSLASHVALIDATOR']._serialized_end=507
  _globals['_MSGSLASHVALIDATORRESPONSE']._serialized_start=509
  _globals['_MSGSLASHVALIDATORRESPONSE']._serialized_end=536
  _globals['_MSG']._serialized_start=538
  _globals['_MSG']._serialized_end=651
# @@protoc_insertion_point(module_scope)
