# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/epochs/epoch_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/epochs/epoch_info.proto\x12\x13\x64ydxprotocol.epochs\"\xb0\x01\n\tEpochInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnext_tick\x18\x02 \x01(\r\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x15\n\rcurrent_epoch\x18\x04 \x01(\r\x12!\n\x19\x63urrent_epoch_start_block\x18\x05 \x01(\r\x12\x16\n\x0eis_initialized\x18\x06 \x01(\x08\x12\x1e\n\x16\x66\x61st_forward_next_tick\x18\x07 \x01(\x08\x42:Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.epochs.epoch_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/types'
  _globals['_EPOCHINFO']._serialized_start=62
  _globals['_EPOCHINFO']._serialized_end=238
# @@protoc_insertion_point(module_scope)
