# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/ratelimit/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as dydxprotocol_dot_ratelimit_dot_limit__params__pb2
from v4_proto.dydxprotocol.ratelimit import capacity_pb2 as dydxprotocol_dot_ratelimit_dot_capacity__pb2
from v4_proto.dydxprotocol.ratelimit import pending_send_packet_pb2 as dydxprotocol_dot_ratelimit_dot_pending__send__packet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dydxprotocol/ratelimit/query.proto\x12\x16\x64ydxprotocol.ratelimit\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a)dydxprotocol/ratelimit/limit_params.proto\x1a%dydxprotocol/ratelimit/capacity.proto\x1a\x30\x64ydxprotocol/ratelimit/pending_send_packet.proto\"\x18\n\x16ListLimitParamsRequest\"_\n\x17ListLimitParamsResponse\x12\x44\n\x11limit_params_list\x18\x01 \x03(\x0b\x32#.dydxprotocol.ratelimit.LimitParamsB\x04\xc8\xde\x1f\x00\",\n\x1bQueryCapacityByDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"l\n\x1cQueryCapacityByDenomResponse\x12L\n\x15limiter_capacity_list\x18\x01 \x03(\x0b\x32\'.dydxprotocol.ratelimit.LimiterCapacityB\x04\xc8\xde\x1f\x00\"#\n!QueryAllPendingSendPacketsRequest\"s\n\"QueryAllPendingSendPacketsResponse\x12M\n\x14pending_send_packets\x18\x01 \x03(\x0b\x32).dydxprotocol.ratelimit.PendingSendPacketB\x04\xc8\xde\x1f\x00\x32\xb8\x04\n\x05Query\x12\xa8\x01\n\x0fListLimitParams\x12..dydxprotocol.ratelimit.ListLimitParamsRequest\x1a/.dydxprotocol.ratelimit.ListLimitParamsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/v4/ratelimit/list_limit_params\x12\xb2\x01\n\x0f\x43\x61pacityByDenom\x12\x33.dydxprotocol.ratelimit.QueryCapacityByDenomRequest\x1a\x34.dydxprotocol.ratelimit.QueryCapacityByDenomResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/v4/ratelimit/capacity_by_denom\x12\xce\x01\n\x15\x41llPendingSendPackets\x12\x39.dydxprotocol.ratelimit.QueryAllPendingSendPacketsRequest\x1a:.dydxprotocol.ratelimit.QueryAllPendingSendPacketsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/dydxprotocol/v4/ratelimit/get_all_pending_send_packetB=Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.ratelimit.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/types'
  _globals['_LISTLIMITPARAMSRESPONSE'].fields_by_name['limit_params_list']._loaded_options = None
  _globals['_LISTLIMITPARAMSRESPONSE'].fields_by_name['limit_params_list']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCAPACITYBYDENOMRESPONSE'].fields_by_name['limiter_capacity_list']._loaded_options = None
  _globals['_QUERYCAPACITYBYDENOMRESPONSE'].fields_by_name['limiter_capacity_list']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE'].fields_by_name['pending_send_packets']._loaded_options = None
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE'].fields_by_name['pending_send_packets']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['ListLimitParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListLimitParams']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/v4/ratelimit/list_limit_params'
  _globals['_QUERY'].methods_by_name['CapacityByDenom']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CapacityByDenom']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/v4/ratelimit/capacity_by_denom'
  _globals['_QUERY'].methods_by_name['AllPendingSendPackets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllPendingSendPackets']._serialized_options = b'\202\323\344\223\0028\0226/dydxprotocol/v4/ratelimit/get_all_pending_send_packet'
  _globals['_LISTLIMITPARAMSREQUEST']._serialized_start=246
  _globals['_LISTLIMITPARAMSREQUEST']._serialized_end=270
  _globals['_LISTLIMITPARAMSRESPONSE']._serialized_start=272
  _globals['_LISTLIMITPARAMSRESPONSE']._serialized_end=367
  _globals['_QUERYCAPACITYBYDENOMREQUEST']._serialized_start=369
  _globals['_QUERYCAPACITYBYDENOMREQUEST']._serialized_end=413
  _globals['_QUERYCAPACITYBYDENOMRESPONSE']._serialized_start=415
  _globals['_QUERYCAPACITYBYDENOMRESPONSE']._serialized_end=523
  _globals['_QUERYALLPENDINGSENDPACKETSREQUEST']._serialized_start=525
  _globals['_QUERYALLPENDINGSENDPACKETSREQUEST']._serialized_end=560
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE']._serialized_start=562
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE']._serialized_end=677
  _globals['_QUERY']._serialized_start=680
  _globals['_QUERY']._serialized_end=1248
# @@protoc_insertion_point(module_scope)
