# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as dydxprotocol_dot_clob_dot_block__rate__limit__config__pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as dydxprotocol_dot_clob_dot_equity__tier__limit__config__pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as dydxprotocol_dot_clob_dot_liquidations__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/clob/genesis.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a/dydxprotocol/clob/block_rate_limit_config.proto\x1a!dydxprotocol/clob/clob_pair.proto\x1a\x30\x64ydxprotocol/clob/equity_tier_limit_config.proto\x1a+dydxprotocol/clob/liquidations_config.proto\"\xbf\x02\n\x0cGenesisState\x12\x35\n\nclob_pairs\x18\x01 \x03(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00\x12H\n\x13liquidations_config\x18\x02 \x01(\x0b\x32%.dydxprotocol.clob.LiquidationsConfigB\x04\xc8\xde\x1f\x00\x12U\n\x17\x62lock_rate_limit_config\x18\x03 \x01(\x0b\x32..dydxprotocol.clob.BlockRateLimitConfigurationB\x04\xc8\xde\x1f\x00\x12W\n\x18\x65quity_tier_limit_config\x18\x04 \x01(\x0b\x32/.dydxprotocol.clob.EquityTierLimitConfigurationB\x04\xc8\xde\x1f\x00\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_GENESISSTATE'].fields_by_name['clob_pairs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['clob_pairs']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['liquidations_config']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['liquidations_config']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['block_rate_limit_config']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['block_rate_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['equity_tier_limit_config']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['equity_tier_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=256
  _globals['_GENESISSTATE']._serialized_end=575
# @@protoc_insertion_point(module_scope)
