# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/vault/params.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\"\x99\x02\n\x06Params\x12\x0e\n\x06layers\x18\x01 \x01(\r\x12\x16\n\x0espread_min_ppm\x18\x02 \x01(\r\x12\x19\n\x11spread_buffer_ppm\x18\x03 \x01(\r\x12\x17\n\x0fskew_factor_ppm\x18\x04 \x01(\r\x12\x1a\n\x12order_size_pct_ppm\x18\x05 \x01(\r\x12 \n\x18order_expiration_seconds\x18\x06 \x01(\r\x12u\n#activation_threshold_quote_quantums\x18\x07 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableIntB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_PARAMS'].fields_by_name['activation_threshold_quote_quantums']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['activation_threshold_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_PARAMS']._serialized_start=78
  _globals['_PARAMS']._serialized_end=359
# @@protoc_insertion_point(module_scope)
