# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vest/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as dydxprotocol_dot_vest_dot_vest__entry__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/vest/query.proto\x12\x11\x64ydxprotocol.vest\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/vest/vest_entry.proto\x1a\x14gogoproto/gogo.proto\"/\n\x15QueryVestEntryRequest\x12\x16\n\x0evester_account\x18\x01 \x01(\t\"K\n\x16QueryVestEntryResponse\x12\x31\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.vest.VestEntryB\x04\xc8\xde\x1f\x00\x32\x94\x01\n\x05Query\x12\x8a\x01\n\tVestEntry\x12(.dydxprotocol.vest.QueryVestEntryRequest\x1a).dydxprotocol.vest.QueryVestEntryResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /dydxprotocol/v4/vest/vest_entryB8Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vest.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/types'
  _globals['_QUERYVESTENTRYRESPONSE'].fields_by_name['entry']._loaded_options = None
  _globals['_QUERYVESTENTRYRESPONSE'].fields_by_name['entry']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['VestEntry']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VestEntry']._serialized_options = b'\202\323\344\223\002\"\022 /dydxprotocol/v4/vest/vest_entry'
  _globals['_QUERYVESTENTRYREQUEST']._serialized_start=140
  _globals['_QUERYVESTENTRYREQUEST']._serialized_end=187
  _globals['_QUERYVESTENTRYRESPONSE']._serialized_start=189
  _globals['_QUERYVESTENTRYRESPONSE']._serialized_end=264
  _globals['_QUERY']._serialized_start=267
  _globals['_QUERY']._serialized_end=415
# @@protoc_insertion_point(module_scope)
