# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/vault.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/vault.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\"F\n\x07VaultId\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"i\n\tNumShares\x12\\\n\nnum_shares\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt*<\n\tVaultType\x12\x1a\n\x16VAULT_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fVAULT_TYPE_CLOB\x10\x01\x42\x39Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.vault_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_NUMSHARES'].fields_by_name['num_shares']._loaded_options = None
  _globals['_NUMSHARES'].fields_by_name['num_shares']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_VAULTTYPE']._serialized_start=255
  _globals['_VAULTTYPE']._serialized_end=315
  _globals['_VAULTID']._serialized_start=76
  _globals['_VAULTID']._serialized_end=146
  _globals['_NUMSHARES']._serialized_start=148
  _globals['_NUMSHARES']._serialized_end=253
# @@protoc_insertion_point(module_scope)
