# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/multisig/v1beta1/multisig.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-cosmos/crypto/multisig/v1beta1/multisig.proto\x12\x1e\x63osmos.crypto.multisig.v1beta1\x1a\x14gogoproto/gogo.proto\"*\n\x0eMultiSignature\x12\x12\n\nsignatures\x18\x01 \x03(\x0c:\x04\xd0\xa1\x1f\x01\"A\n\x0f\x43ompactBitArray\x12\x19\n\x11\x65xtra_bits_stored\x18\x01 \x01(\r\x12\r\n\x05\x65lems\x18\x02 \x01(\x0c:\x04\x98\xa0\x1f\x00\x42+Z)github.com/cosmos/cosmos-sdk/crypto/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.multisig.v1beta1.multisig_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/crypto/types'
  _globals['_MULTISIGNATURE']._loaded_options = None
  _globals['_MULTISIGNATURE']._serialized_options = b'\320\241\037\001'
  _globals['_COMPACTBITARRAY']._loaded_options = None
  _globals['_COMPACTBITARRAY']._serialized_options = b'\230\240\037\000'
  _globals['_MULTISIGNATURE']._serialized_start=103
  _globals['_MULTISIGNATURE']._serialized_end=145
  _globals['_COMPACTBITARRAY']._serialized_start=147
  _globals['_COMPACTBITARRAY']._serialized_end=212
# @@protoc_insertion_point(module_scope)
